ormm.opt package
================

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   ormm.opt.mathprog

Module contents
---------------

.. automodule:: ormm.opt
   :members:
   :undoc-members:
   :show-inheritance:
